================
Pop Docs Outline
================

POP docs need to cover how to write and think in POP in a way that is consumabe,
has many visuals and covers the basic concepts in an easy, follow along way.

Quickstart
==========

Get started with pop-seed to make a simple standalone project. This makes a project
that can be executed easily.

Go from pop-seed all the way to defining dynamic names and using tiamat.

Quickstart Vertical
===================

Cover how to make vertical app-merge projects using pop-seed and dyne name

What is POP?
============

Declare the problem statement-
Exlplain what POP is, and how it seeks to solve this problem.

Origin
======

Where did POP come from, and how does that lend the concept credibility?

What does Pluggable mean?
=========================

Pluggable code means that your applications become legos, endlessly attatchable

Intro the hub, app merging, plugins and why conf needs to be integrated

Why Patterns are so critical

The Hub
=======

The root of the application and namespaces. Cover why namespaces are critical
in POP and why they need to be shared

App Merging
===========

App Merging, the core feature and concept of POP

Plugins, what this means
========================

Cover what Pluggins are and what it means to make pluggable software

The Conf System
===============

Why the conf system is needed, how it works and how it allows app merging to happen

Thinking in POP
===============

POP makes you think about code differently, learn how to think in plugin systems as
I/O interfaces that expose consistent, pluggable systems.

Structure concepts
==================

Get familiar with the layout of pop projects, the hub and subs, how they lay out
and communicate


What Goes Where
===============

What goes in __init__
---------------------

Define what goes in the __init__ func and what does not go in the __init__ func

Vars and subs
-------------

Expose the conventions about how to place variables on the hub, where they go and
what they mean, what does read/write look like

Using Sub subs
--------------

When to use subs wihthin subs and hwo it relates to data access patterns

Contracts For Enforcement
-------------------------

Cover how and when to use contracts

Understanding Patterns
======================

Pop is all about making patters inside of subs, if patterns are not being made then
the code is not pop

Define what a pattern is and how to think about making patterns
